==> multiple-quick-koa-7.5.5.tgz: package/core/file/plugins/model/service.js <==
const fs = require('fs')
const path = require('path')

exports.loadModel = async ({ app, appName }) => {
  const data = fs.readdirSync(
    path.resolve(__dirname, `${process.cwd()}/app/${appName}/plugins`)
  )

  const modelList = await app.model.model.findAll({ raw: true })

  await Promise.all(
    ['model', 'model_attributes'].map((item) =>
      app.model[item].sync({
        force: true,
      })
    )
  )

  const dataList = []
  const result = data.filter(
    (item) => !['model', 'model_attributes'].includes(item)
  )
  for (let i = 0; i < result.length; i++) {
    const filePath = path.resolve(
      __dirname,
      `${process.cwd()}/app/${appName}/plugins/${result[i]}/model.js`
    )
    const configPath = path.resolve(
      __dirname,
      `${process.cwd()}/app/${appName}/plugins/${result[i]}/config.js`
    )
    const defaultFilePath = path.resolve(__dirname, `../${result[i]}/model.js`)
    const defaultConfigPath = path.resolve(
      __dirname,
      `../${result[i]}/config.js`
    )

    const modelExist = fs.existsSync(filePath)
    const defaultModelExist = fs.existsSync(defaultFilePath)
    const configExist = fs.existsSync(configPath)
    if (configExist) {
      const config = fs.readFileSync(configPath, 'utf-8')
        ? require(configPath)
        : require(defaultConfigPath)

      const modelFile =
        defaultModelExist || modelExist
          ? fs.readFileSync(filePath, 'utf-8')
            ? fs.readFileSync(filePath, 'utf-8')
            : fs.readFileSync(defaultFilePath, 'utf-8')
          : null

      const model = modelFile
        ? fs.readFileSync(filePath, 'utf-8')
          ? require(filePath)
          : require(defaultFilePath)
        : {}
      const attributes = modelFile ? modelFile.match(/exports.(.*)=/g) : []
      const types = modelFile ? modelFile.match(/Sequelize.(.*),\n/g) : {}

      const ori_target = modelList.find((m) => m.model === result[i])
      const id = ori_target ? ori_target.id : null
      const obj = {
        id,
        model: result[i],
        name: config.name,
        belongs: config.belongs || 'page',
        order: config.order,
        multiple: config.multiple,
        availableSort: config.availableSort,
        limit: config.limit || 20,
        select: config.select,
        excludes: config.excludes,
        initList: config.initList,
        defaultOrder: config.defaultOrder,
        excludeAuth: config.excludeAuth,
        comment: config.comment,
        reference: config.reference,
        include: config.include,
        sortOrder: config.sortOrder,
        personal: config.personal,
        autoData: config.autoData,
        is_split: config.is_split,
        is_split_count: config.is_split_count,
        show_virtual: config.show_virtual,
        modelQuery: config.modelQuery,
        editInline: config.editInline,
        deleteCheckList: config.deleteCheckList,
        list: attributes.map((attr, index) => {
          const name = attr.match(/exports.(.*)=/)[1].trim()
          let defaultValue = ''
          if (model[name] && model[name].hasOwnProperty('defaultValue')) {
            if (
              typeof model[name].defaultValue === 'boolean' &&
              model[name].defaultValue === true
            ) {
              defaultValue = 'true'
            }
            if (
              typeof model[name].defaultValue === 'boolean' &&
              model[name].defaultValue === false
            ) {
              defaultValue = 'false'
            }
            if (typeof model[name].defaultValue === 'number') {
              defaultValue = `${model[name].defaultValue}`
            }
            if (Array.isArray(model[name].defaultValue)) {
              defaultValue = '[]'
            }
            if (
              Object.prototype.toString.call(model[name].defaultValue) ===
              '[object Object]'
            ) {
              defaultValue = '{}'
            }
            if (
              typeof model[name].defaultValue === 'string' &&
              model[name].defaultValue === ''
            ) {
              defaultValue = "''"
            }
            if (
              typeof model[name].defaultValue === 'string' &&
              model[name].defaultValue !== ''
            ) {
              defaultValue = `'${model[name].defaultValue}'`
            }
            if (
              !model[name].defaultValue &&
              typeof model[name].defaultValue !== 'undefined' &&
              model[name].defaultValue != 0
            ) {
              defaultValue = 'null'
            }
            if (
              types[index] &&
              types[index].includes('DATE') &&
              model[name].allowNull === true
            ) {
              defaultValue = 'null'
            }
          } else if (
            model[name] &&
            !model[name].hasOwnProperty('defaultValue')
          ) {
            defaultValue = "''"
          }

          return {
            model_id: id || i + 1,
            name,
            type: types[index] ? types[index].replace(/,\n/, '') : '',
            comment: model[name] ? model[name].comment : '',
            is_mock:
              model[name] && model[name].is_mock
                ? model[name].is_mock
                : !!(model[name] && model[name].mock),
            allowNull:
              model[name] && model[name].allowNull
                ? model[name].allowNull
                : false,
            defaultValue,
            sortOrder:
              model[name] && model[name].sortOrder
                ? Number(model[name].sortOrder)
                : 1,
            mock:
              model[name] && model[name].mock
                ? model[name].mock.toString()
                : '',
            set:
              model[name] && model[name].set ? model[name].set.toString() : '',
            get:
              model[name] && model[name].get ? model[name].get.toString() : '',
            belongsTo: model[name] ? model[name].belongsTo : '',
            unique: !!(model[name] && model[name].hasOwnProperty('unique')),
            hasOne: !!(model[name] && model[name].hasOwnProperty('hasOne')),
            validate:
              model[name] && model[name].validate
                ? JSON.stringify(model[name].validate)
                : null,
            extra:
              model[name] && model[name].extra
                ? JSON.stringify(model[name].extra)
                : null,
          }
        }),
      }
      if (obj.model === 'user_free') {
        console.log(obj)
      }
      dataList.push(obj)
    }
  }

  const promise1 = app.model.model.bulkCreate(
    dataList.map((item) => {
      return {
        ...item,
        list: item.list.filter((t) => t.type),
      }
    })
  )
  const promise2 = app.model.model_attributes.bulkCreate(
    dataList
      .filter((item) => item.list.every((t) => t.type))
      .reduce((a, b) => [...a, ...b.list], [])
  )

  await Promise.all([promise1, promise2])
  console.log('lodaModel success!')
  if (app.service.routes && app.model.routes) {
    await app.service.routes.initRouter({ app })
  } else {
    console.warn('routes可能没有service.js')
  }
}

==> multiple-quick-koa-7.6.6.tgz: package/core/file/plugins/model/service.js <==
const fs = require('fs')
const path = require('path')

exports.loadModel = async ({ app, appName }) => {
  const data = fs.readdirSync(
    path.resolve(__dirname, `${process.cwd()}/app/${appName}/plugins`)
  )

  const modelList = await app.model.model.findAll({ raw: true })

  await Promise.all(
    ['model', 'model_attributes'].map((item) =>
      app.model[item].sync({
        force: true,
      })
    )
  )

  const dataList = []
  const result = data.filter(
    (item) => !['model', 'model_attributes'].includes(item)
  )
  for (let i = 0; i < result.length; i++) {
    const filePath = path.resolve(
      __dirname,
      `${process.cwd()}/app/${appName}/plugins/${result[i]}/model.js`
    )
    const configPath = path.resolve(
      __dirname,
      `${process.cwd()}/app/${appName}/plugins/${result[i]}/config.js`
    )
    const defaultFilePath = path.resolve(__dirname, `../${result[i]}/model.js`)
    const defaultConfigPath = path.resolve(
      __dirname,
      `../${result[i]}/config.js`
    )

    const modelExist = fs.existsSync(filePath)
    const defaultModelExist = fs.existsSync(defaultFilePath)
    const configExist = fs.existsSync(configPath)
    if (configExist) {
      const config = fs.readFileSync(configPath, 'utf-8')
        ? require(configPath)
        : require(defaultConfigPath)

      const modelFile =
        defaultModelExist || modelExist
          ? fs.readFileSync(filePath, 'utf-8')
            ? fs.readFileSync(filePath, 'utf-8')
            : fs.readFileSync(defaultFilePath, 'utf-8')
          : null

      const model = modelFile
        ? fs.readFileSync(filePath, 'utf-8')
          ? require(filePath)
          : require(defaultFilePath)
        : {}
      const attributes = modelFile ? modelFile.match(/exports.(.*)=/g) : []
      const types = modelFile ? modelFile.match(/Sequelize.(.*),\n/g) : {}

      const ori_target = modelList.find((m) => m.model === result[i])
      const id = ori_target ? ori_target.id : null
      const obj = {
        id,
        model: result[i],
        name: config.name,
        belongs: config.belongs || 'page',
        order: config.order,
        multiple: config.multiple,
        availableSort: config.availableSort,
        limit: config.limit || 20,
        select: config.select,
        excludes: config.excludes,
        initList: config.initList,
        defaultOrder: config.defaultOrder,
        excludeAuth: config.excludeAuth,
        comment: config.comment,
        reference: config.reference,
        include: config.include,
        sortOrder: config.sortOrder,
        personal: config.personal,
        autoData: config.autoData,
        is_split: config.is_split,
        is_split_count: config.is_split_count,
        show_virtual: config.show_virtual,
        modelQuery: config.modelQuery,
        editInline: config.editInline,
        deleteCheckList: config.deleteCheckList,
        list: attributes.map((attr, index) => {
          const name = attr.match(/exports.(.*)=/)[1].trim()
          let defaultValue = ''
          if (model[name] && model[name].hasOwnProperty('defaultValue')) {
            if (
              typeof model[name].defaultValue === 'boolean' &&
              model[name].defaultValue === true
            ) {
              defaultValue = 'true'
            }
            if (
              typeof model[name].defaultValue === 'boolean' &&
              model[name].defaultValue === false
            ) {
              defaultValue = 'false'
            }
            if (typeof model[name].defaultValue === 'number') {
              defaultValue = `${model[name].defaultValue}`
            }
            if (Array.isArray(model[name].defaultValue)) {
              defaultValue = '[]'
            }
            if (
              Object.prototype.toString.call(model[name].defaultValue) ===
              '[object Object]'
            ) {
              defaultValue = '{}'
            }
            if (
              typeof model[name].defaultValue === 'string' &&
              model[name].defaultValue === ''
            ) {
              defaultValue = "''"
            }
            if (
              typeof model[name].defaultValue === 'string' &&
              model[name].defaultValue !== ''
            ) {
              defaultValue = `'${model[name].defaultValue}'`
            }
            if (
              !model[name].defaultValue &&
              typeof model[name].defaultValue !== 'undefined' &&
              model[name].defaultValue != 0
            ) {
              defaultValue = 'null'
            }
            if (
              types[index] &&
              types[index].includes('DATE') &&
              model[name].allowNull === true
            ) {
              defaultValue = 'null'
            }
          } else if (
            model[name] &&
            !model[name].hasOwnProperty('defaultValue')
          ) {
            defaultValue = "''"
          }

          return {
            model_id: id || i + 1,
            name,
            type: types[index] ? types[index].replace(/,\n/, '') : '',
            comment: model[name] ? model[name].comment : '',
            is_mock:
              model[name] && model[name].is_mock
                ? model[name].is_mock
                : !!(model[name] && model[name].mock),
            allowNull:
              model[name] && model[name].allowNull
                ? model[name].allowNull
                : false,
            defaultValue,
            sortOrder:
              model[name] && model[name].sortOrder
                ? Number(model[name].sortOrder)
                : 1,
            mock:
              model[name] && model[name].mock
                ? model[name].mock.toString()
                : '',
            set:
              model[name] && model[name].set ? model[name].set.toString() : '',
            get:
              model[name] && model[name].get ? model[name].get.toString() : '',
            belongsTo: model[name] ? model[name].belongsTo : '',
            unique: !!(model[name] && model[name].hasOwnProperty('unique')),
            hasOne: !!(model[name] && model[name].hasOwnProperty('hasOne')),
            validate:
              model[name] && model[name].validate
                ? JSON.stringify(model[name].validate)
                : null,
            extra:
              model[name] && model[name].extra
                ? JSON.stringify(model[name].extra)
                : null,
          }
        }),
      }
      // if (obj.model === 'user_free') {
      //   console.log(obj)
      // }
      dataList.push(obj)
    }
  }

  const promise1 = app.model.model.bulkCreate(
    dataList.map((item) => {
      return {
        ...item,
        list: item.list.filter((t) => t.type),
      }
    })
  )
  const promise2 = app.model.model_attributes.bulkCreate(
    dataList
      .filter((item) => item.list.every((t) => t.type))
      .reduce((a, b) => [...a, ...b.list], [])
  )

  await Promise.all([promise1, promise2])
  console.log('lodaModel success!')
  if (app.service.routes && app.model.routes) {
    await app.service.routes.initRouter({ app })
  } else {
    console.warn('routes可能没有service.js')
  }
}
